==> rutorrent-3.9.tar.gz: ruTorrent-3.9/plugins/rss/lang/vi.js <==
﻿/*
 * PLUGIN RSS
 *
 * Vietnamese language file.
 *
 * Author: Ta Xuan Truong (truongtx8 AT gmail DOT com)
 */

 theUILang.addRSS			= "Thêm nguồn RSS";
 theUILang.feedURL			= "Đường dẫn";
 theUILang.alias			= "Tùy chọn Bí Danh";
 theUILang.rssAuto			= "Tự động tải các mục từ nguồn";
 theUILang.allFeeds			= "Tất cả các nguồn";
 theUILang.incorrectURL 		= "Vui lòng chỉ đường dẫn nguồn một cách chính xác."
 theUILang.cantFetchRSS 		= "Lỗi khi tải nguồn.";
 theUILang.rssAlreadyExist		= "Nguồn này đã có rồi.";
 theUILang.rssDontExist 		= "Nguồn không tồn tại";
 theUILang.rssCantLoadTorrent		= "Lỗi tải torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Đã tải";
 theUILang.rssMenuLoad			= "Tải";
 theUILang.rssMenuOpen			= "Mở trong trình duyệt";
 theUILang.rssMenuClearHistory		= "Xóa lịch sử";
 theUILang.rssMenuAddToFilter		= "Thêm vào Danh sách Thích";
 theUILang.rssMenuManager		= "Quản lý RSS";
 theUILang.rssMenuRefresh		= "Cập nhật nguồn";
 theUILang.rssMenuDisable		= "Vô hiệu hóa nguồn";
 theUILang.rssMenuEnable		= "Kích hoạt nguồn";
 theUILang.rssMenuEdit			= "Chỉnh sửa nguồn";
 theUILang.rssMenuDelete		= "Xóa nguồn";
 theUILang.rssDeletePrompt		= "Bạn có thực sự muốn xóa nguồn đã chọn?";
 theUILang.rssNewFilter 		= "Tạo bộ lọc mới";
 theUILang.rssFilter			= "Bộ lọc";
 theUILang.rssAddFilter 		= "Thêm";
 theUILang.rssDelFilter 		= "Xóa";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Cài đặt bộ lọc";
 theUILang.rssIncorrectFilter		= "Bộ lọc không đúng.";
 theUILang.foundedByFilter		= "Khớp";
 theUILang.rssExclude			= "Loại trừ";
 theUILang.rssStatusError		= "Lỗi khi tải";
 theUILang.rssFeeds			= "Nguồn tin";
 theUILang.rssCheckTitle		= "Kiểm tra phần Đề mục";
 theUILang.rssCheckDescription		= "Kiểm tra phần Mô tả";
 theUILang.rssCheckLink 		= "Kiểm tra phần đường dẫn";
 theUILang.rssMinInterval		= "Khoảng thời gian tối thiểu";
 theUILang.rssIntervalAlways		= "(luôn trùng khớp)";
 theUILang.rssIntervalOnce		= "(chỉ trùng một lần)";
 theUILang.rssInterval12h		= "12 tiếng";
 theUILang.rssInterval1d		= "1 ngày";
 theUILang.rssInterval2d		= "2 ngày";
 theUILang.rssInterval3d		= "3 ngày";
 theUILang.rssInterval4d		= "4 ngày";
 theUILang.rssInterval6d		= "6 ngày";
 theUILang.rssInterval1w		= "1 tuần";
 theUILang.rssInterval2w		= "2 tuần";
 theUILang.rssInterval3w		= "3 tuần";
 theUILang.rssInterval1m		= "1 tháng";
 theUILang.rssClearFilter		= "Đặt lại";
 theUILang.rssMarkAs			= "Đánh dấu thành";
 theUILang.rssAsLoaded			= "đã tải";
 theUILang.rssAsUnloaded		= "chưa tải";
 theUILang.addRSSGroup			= "Thêm nhóm RSS";
 theUILang.editRSSGroup 		= "Sửa nhóm RSS";
 theUILang.addRSSGroupContent		= "Nội dung";
 theUILang.rssMenuGroupDisable		= "Vô hiệu hóa nhóm";
 theUILang.rssMenuGroupRefresh		= "Cập nhật nhóm";
 theUILang.rssMenuGroupEnable		= "Kích hoạt nhóm";
 theUILang.rssMenuGroupEdit		= "Thay đổi nhóm";
 theUILang.rssMenuGroupDelete		= "Xóa nhóm";
 theUILang.rssMenuGroupContentsDelete	= "Xóa nội dung";
 theUILang.rssDeleteGroupPrompt 	= "Bạn có thực sự muốn xóa các nhóm đã chọn?";
 theUILang.rssDeleteGroupContentsPrompt = "Bạn có thực sự muốn xóa các nhóm đã chọn và toạn bộ nội dung bên trong?";
 theUILang.rssAllFiters 		= "Tất cả bộ lọc";
 theUILang.rssUpdateInterval 		= "Cập nhật sau mỗi";
 theUILang.Directories			= "Các thư mục";
 theUILang.Labels			= "Các nhãn";

thePlugins.get("rss").langLoaded();

==> rutorrent-4.3.6.tar.gz: ruTorrent-4.3.6/plugins/rss/lang/vi.js <==
﻿/*
 * PLUGIN RSS
 *
 * Vietnamese language file.
 *
 * Author: Ta Xuan Truong (truongtx8 AT gmail DOT com)
 */

 theUILang.addRSS			= "Thêm nguồn RSS";
 theUILang.feedURL			= "Đường dẫn";
 theUILang.alias			= "Tùy chọn Bí Danh";
 theUILang.rssAuto			= "Tự động tải các mục từ nguồn";
 theUILang.allFeeds			= "Tất cả các nguồn";
 theUILang.incorrectURL			= "Vui lòng chỉ đường dẫn nguồn một cách chính xác.";
 theUILang.cantFetchRSS			= "Lỗi khi tải nguồn.";
 theUILang.rssAlreadyExist		= "Nguồn này đã có rồi.";
 theUILang.rssDontExist			= "Nguồn không tồn tại.";
 theUILang.rssCantLoadTorrent		= "Lỗi tải torrent.";
 theUILang.rssStatus			= "RSS";
 theUILang.rssStatusLoaded		= "Đã tải";
 theUILang.rssMenuLoad			= "Tải";
 theUILang.rssMenuOpen			= "Mở trong trình duyệt";
 theUILang.rssMenuClearHistory		= "Xóa lịch sử";
 theUILang.rssMenuAddToFilter		= "Thêm vào Danh sách Thích";
 theUILang.rssMenuManager		= "Quản lý RSS";
 theUILang.rssMenuRefresh		= "Cập nhật nguồn";
 theUILang.rssMenuDisable		= "Vô hiệu hóa nguồn";
 theUILang.rssMenuEnable		= "Kích hoạt nguồn";
 theUILang.rssMenuEdit			= "Chỉnh sửa nguồn";
 theUILang.rssMenuDelete		= "Xóa nguồn";
 theUILang.rssDeletePrompt		= "Bạn có thực sự muốn xóa nguồn đã chọn?";
 theUILang.rssNewFilter			= "Tạo bộ lọc mới";
 theUILang.rssFilter			= "Bộ lọc";
 theUILang.rssAddFilter			= "Thêm";
 theUILang.rssDelFilter			= "Xóa";
 theUILang.rssCheckFilter		= "?";
 theUILang.rssFiltersLegend		= "Cài đặt bộ lọc";
 theUILang.rssIncorrectFilter		= "Bộ lọc không đúng.";
 theUILang.foundedByFilter		= "Khớp";
 theUILang.rssExclude			= "Loại trừ";
 theUILang.rssStatusError		= "Lỗi khi tải";
 theUILang.rssFeeds			= "Nguồn tin";
 theUILang.rssCheckTitle		= "Kiểm tra phần Đề mục";
 theUILang.rssCheckDescription		= "Kiểm tra phần Mô tả";
 theUILang.rssCheckLink			= "Kiểm tra phần đường dẫn";
 theUILang.rssMinInterval		= "Khoảng thời gian tối thiểu";
 theUILang.rssIntervalAlways		= "(luôn trùng khớp)";
 theUILang.rssIntervalOnce		= "(chỉ trùng một lần)";
 theUILang.rssInterval12h		= "12 tiếng";
 theUILang.rssInterval1d		= "1 ngày";
 theUILang.rssInterval2d		= "2 ngày";
 theUILang.rssInterval3d		= "3 ngày";
 theUILang.rssInterval4d		= "4 ngày";
 theUILang.rssInterval6d		= "6 ngày";
 theUILang.rssInterval1w		= "1 tuần";
 theUILang.rssInterval2w		= "2 tuần";
 theUILang.rssInterval3w		= "3 tuần";
 theUILang.rssInterval1m		= "1 tháng";
 theUILang.rssClearFilter		= "Đặt lại";
 theUILang.rssMarkAs			= "Đánh dấu thành";
 theUILang.rssAsLoaded			= "đã tải";
 theUILang.rssAsUnloaded		= "chưa tải";
 theUILang.addRSSGroup			= "Thêm nhóm RSS";
 theUILang.editRSSGroup			= "Sửa nhóm RSS";
 theUILang.addRSSGroupContent		= "Nội dung";
 theUILang.rssMenuGroupDisable		= "Vô hiệu hóa nhóm";
 theUILang.rssMenuGroupRefresh		= "Cập nhật nhóm";
 theUILang.rssMenuGroupEnable		= "Kích hoạt nhóm";
 theUILang.rssMenuGroupEdit		= "Thay đổi nhóm";
 theUILang.rssMenuGroupDelete		= "Xóa nhóm";
 theUILang.rssMenuGroupContentsDelete	= "Xóa nội dung";
 theUILang.rssDeleteGroupPrompt		= "Bạn có thực sự muốn xóa các nhóm đã chọn?";
 theUILang.rssDeleteGroupContentsPrompt	= "Bạn có thực sự muốn xóa các nhóm đã chọn và toạn bộ nội dung bên trong?";
 theUILang.rssAllFiters			= "Tất cả bộ lọc";
 theUILang.rssUpdateInterval		= "Cập nhật sau mỗi";
 theUILang.rssShowErrorsDelayed		= "Delay RSS error notification until the log tab or RSS feed is visible";
 theUILang.Directories			= "Các thư mục";
 theUILang.Labels			= "Các nhãn";

thePlugins.get("rss").langLoaded();
